/*
 * Copyright (C) 2015 Tet Woo Lee
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package nz.twlee.imagej.common;

import ij.gui.GenericDialog;
import java.util.List;

/**
 *
 * @author Tet Woo Lee
 */
public abstract class AbstractParameter implements Parameter {
    String name;
    String description;
    
    String getDialogText() {
        return name+" : "+description;
    }
    
    public static void loadParameters(List<Parameter> parameters) {
        for (Parameter parameter:parameters) parameter.loadParameter();
    }
    
    public static void saveParameters(List<Parameter> parameters) {
        for (Parameter parameter:parameters) parameter.saveParameter();
    }
    
    public static void showOptionsDialog(List<Parameter> parameters, String dialogTitle) {
        
        GenericDialog dialog = new GenericDialog(dialogTitle);
        for (Parameter parameter:parameters) {
            parameter.populateDialog(dialog);
        }
        dialog.showDialog();
        
        if (dialog.wasCanceled()) return;

        for (Parameter parameter:parameters) {
            parameter.retrieveFromDialog(dialog);
        }
        saveParameters(parameters);
        ij.Prefs.savePreferences();
        
    }
}
